summaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/include/dspbridge/proc.h
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-09 21:24:00 -0500
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 10:45:35 -0700
commite436d07db9db374105daa6c15d853e3f13a37104 (patch)
tree863785b582646946fe08c909113c04627a683cf4 /drivers/staging/tidspbridge/include/dspbridge/proc.h
parenta5120278008a5f48634085c23a70f1153065765d (diff)
downloadop-kernel-dev-e436d07db9db374105daa6c15d853e3f13a37104.zip
op-kernel-dev-e436d07db9db374105daa6c15d853e3f13a37104.tar.gz
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== phDevContext to device_ctx phDevNode to dev_nde phDevObject to device_obj phDispObject to dispatch_obj phDmmMgr to dmm_manager phDrvObject to drv_obj phDRVObject to drv_obj phIOMgr to io_man phLoader to loader phManager to manager phMgrObject to mgr_obj phMgr to mgr phMsgMgr to msg_man phMsgQueue to msgq phNldrNode to nldr_nodeobj ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/proc.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/proc.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/proc.h b/drivers/staging/tidspbridge/include/dspbridge/proc.h
index 11fdc97..cbd26dc 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/proc.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/proc.h
@@ -208,19 +208,19 @@ extern void proc_exit(void);
* Returns the DEV Hanlde for a given Processor handle
* Parameters:
* hprocessor : Processor Handle
* phDevObject : Location to store the DEV Handle.
* Returns:
* 0 : Success; *phDevObject has Dev handle
* -EPERM : Failure; *phDevObject is zero.
* Requires:
- * phDevObject is not NULL
+ * device_obj is not NULL
* PROC Initialized.
* Ensures:
- * 0 : *phDevObject is not NULL
- * -EPERM : *phDevObject is NULL.
+ * 0 : *device_obj is not NULL
+ * -EPERM : *device_obj is NULL.
*/
extern int proc_get_dev_object(void *hprocessor,
- struct dev_object **phDevObject);
+ struct dev_object **device_obj);
/*
* ======== proc_init ========
OpenPOWER on IntegriCloud
@@ -208,19 +208,19 @@ extern void proc_exit(void);
* Parameters:
* hprocessor : Processor Handle
- * phDevObject : Location to store the DEV Handle.
+ * device_obj : Location to store the DEV Handle.
* Returns:
@@ -208,19 +208,19 @@ extern void proc_exit(void);
* Returns:
- * 0 : Success; *phDevObject has Dev handle
- * -EPERM : Failure; *phDevObject is zero.
+ * 0 : Success; *device_obj has Dev handle
+ * -EPERM : Failure; *device_obj is zero.
* Requires: